summaryrefslogtreecommitdiff
path: root/nuttx/configs/lm3s6432-s2e/src
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-01-09 14:48:55 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-01-09 14:48:55 +0000
commit25f65f6524fe5c6508de38300796e1183051ab3b (patch)
tree3b685616dd8e36f94fabb4c9ce2dc19c9065b394 /nuttx/configs/lm3s6432-s2e/src
parent6afb58c74e1b0bbfe3306e1a3a00d31462c598fa (diff)
downloadpx4-nuttx-25f65f6524fe5c6508de38300796e1183051ab3b.tar.gz
px4-nuttx-25f65f6524fe5c6508de38300796e1183051ab3b.tar.bz2
px4-nuttx-25f65f6524fe5c6508de38300796e1183051ab3b.zip
Rename LM3S files, variables, and types from lm3s_ to lm_; Rename configuration variables from CONFIG_LM3S_ to CONFIG_LM_
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5497 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/configs/lm3s6432-s2e/src')
-rw-r--r--nuttx/configs/lm3s6432-s2e/src/lm3s6432s2e_internal.h4
-rw-r--r--nuttx/configs/lm3s6432-s2e/src/up_boot.c20
-rw-r--r--nuttx/configs/lm3s6432-s2e/src/up_ethernet.c8
-rw-r--r--nuttx/configs/lm3s6432-s2e/src/up_leds.c22
-rw-r--r--nuttx/configs/lm3s6432-s2e/src/up_ssi.c26
5 files changed, 40 insertions, 40 deletions
diff --git a/nuttx/configs/lm3s6432-s2e/src/lm3s6432s2e_internal.h b/nuttx/configs/lm3s6432-s2e/src/lm3s6432s2e_internal.h
index f54403c7a..f95b118ad 100644
--- a/nuttx/configs/lm3s6432-s2e/src/lm3s6432s2e_internal.h
+++ b/nuttx/configs/lm3s6432-s2e/src/lm3s6432s2e_internal.h
@@ -112,14 +112,14 @@
#ifndef __ASSEMBLY__
/************************************************************************************
- * Name: lm3s_ssiinitialize
+ * Name: lm_ssiinitialize
*
* Description:
* Called to configure SPI chip select GPIO pins for the MDL-S2E.
*
************************************************************************************/
-extern void weak_function lm3s_ssiinitialize(void);
+extern void weak_function lm_ssiinitialize(void);
#endif /* __ASSEMBLY__ */
#endif /* __CONFIGS_LM3S6432_S2E_SRC_LM3S6432S2E_INTERNAL_H */
diff --git a/nuttx/configs/lm3s6432-s2e/src/up_ethernet.c b/nuttx/configs/lm3s6432-s2e/src/up_ethernet.c
index 09d5040c4..434ffe2c5 100644
--- a/nuttx/configs/lm3s6432-s2e/src/up_ethernet.c
+++ b/nuttx/configs/lm3s6432-s2e/src/up_ethernet.c
@@ -63,17 +63,17 @@
************************************************************************************/
/************************************************************************************
- * Name: lm3s_ethernetmac
+ * Name: lm_ethernetmac
*
* Description:
* For the Ethernet Eval Kits, the MAC address will be stored in the non-volatile
- * USER0 and USER1 registers. If CONFIG_LM3S_BOARDMAC is defined, this function
+ * USER0 and USER1 registers. If CONFIG_LM_BOARDMAC is defined, this function
* will obtain the MAC address from these registers.
*
************************************************************************************/
-#ifdef CONFIG_LM3S_BOARDMAC
-void lm3s_ethernetmac(struct ether_addr *ethaddr)
+#ifdef CONFIG_LM_BOARDMAC
+void lm_ethernetmac(struct ether_addr *ethaddr)
{
uint32_t user0;
uint32_t user1;
diff --git a/nuttx/configs/lm3s6432-s2e/src/up_leds.c b/nuttx/configs/lm3s6432-s2e/src/up_leds.c
index 81610db34..e0dd53f28 100644
--- a/nuttx/configs/lm3s6432-s2e/src/up_leds.c
+++ b/nuttx/configs/lm3s6432-s2e/src/up_leds.c
@@ -72,7 +72,7 @@
/* Dump GPIO registers */
#ifdef LED_DEBUG
-# define led_dumpgpio(m) lm3s_dumpgpio(LED_GPIO, m)
+# define led_dumpgpio(m) lm_dumpgpio(LED_GPIO, m)
#else
# define led_dumpgpio(m)
#endif
@@ -102,10 +102,10 @@ void up_ledinit(void)
/* Configure Port F, Bit 2 as an output, initial value=OFF */
- led_dumpgpio("up_ledinit before lm3s_configgpio()");
- lm3s_configgpio(LED0_GPIO);
- lm3s_configgpio(LED1_GPIO);
- led_dumpgpio("up_ledinit after lm3s_configgpio()");
+ led_dumpgpio("up_ledinit before lm_configgpio()");
+ lm_configgpio(LED0_GPIO);
+ lm_configgpio(LED1_GPIO);
+ led_dumpgpio("up_ledinit after lm_configgpio()");
g_nest = 0;
}
@@ -129,9 +129,9 @@ void up_ledon(int led)
g_nest++;
case LED_IRQSENABLED:
case LED_STACKCREATED:
- led_dumpgpio("up_ledon: before lm3s_gpiowrite()");
- lm3s_gpiowrite(LED1_GPIO, false);
- led_dumpgpio("up_ledon: after lm3s_gpiowrite()");
+ led_dumpgpio("up_ledon: before lm_gpiowrite()");
+ lm_gpiowrite(LED1_GPIO, false);
+ led_dumpgpio("up_ledon: after lm_gpiowrite()");
break;
}
}
@@ -157,9 +157,9 @@ void up_ledoff(int led)
case LED_PANIC:
if (--g_nest <= 0)
{
- led_dumpgpio("up_ledoff: before lm3s_gpiowrite()");
- lm3s_gpiowrite(LED1_GPIO, true);
- led_dumpgpio("up_ledoff: after lm3s_gpiowrite()");
+ led_dumpgpio("up_ledoff: before lm_gpiowrite()");
+ lm_gpiowrite(LED1_GPIO, true);
+ led_dumpgpio("up_ledoff: after lm_gpiowrite()");
}
break;
}
diff --git a/nuttx/configs/lm3s6432-s2e/src/up_boot.c b/nuttx/configs/lm3s6432-s2e/src/up_boot.c
index 184529638..da900282f 100644
--- a/nuttx/configs/lm3s6432-s2e/src/up_boot.c
+++ b/nuttx/configs/lm3s6432-s2e/src/up_boot.c
@@ -54,7 +54,7 @@
* Definitions
************************************************************************************/
-#if defined(CONFIG_LM3S_UART1) && !defined(CONFIG_SSI0_DISABLE)
+#if defined(CONFIG_LM_UART1) && !defined(CONFIG_SSI0_DISABLE)
# error Only one of UART1 and SSI0 can be enabled on this board.
#endif
@@ -67,7 +67,7 @@
************************************************************************************/
/************************************************************************************
- * Name: lm3s_boardinitialize
+ * Name: lm_boardinitialize
*
* Description:
* All LM3S architectures must provide the following entry point. This entry point
@@ -75,16 +75,16 @@
* and mapped but before any devices have been initialized.
************************************************************************************/
-void lm3s_boardinitialize(void)
+void lm_boardinitialize(void)
{
/* Configure SPI chip selects if 1) SSI is not disabled, and 2) the weak function
* lm3s_ssiinitialize() has been brought into the link.
*/
#if !defined(CONFIG_SSI0_DISABLE)
- if (lm3s_ssiinitialize)
+ if (lm_ssiinitialize)
{
- lm3s_ssiinitialize();
+ lm_ssiinitialize();
}
#endif
@@ -96,8 +96,8 @@ void lm3s_boardinitialize(void)
/* Configure serial transciever */
- lm3s_configgpio(XCVR_INV_GPIO);
- lm3s_configgpio(XCVR_ENA_GPIO);
- lm3s_configgpio(XCVR_ON_GPIO);
- lm3s_configgpio(XCVR_OFF_GPIO);
+ lm_configgpio(XCVR_INV_GPIO);
+ lm_configgpio(XCVR_ENA_GPIO);
+ lm_configgpio(XCVR_ON_GPIO);
+ lm_configgpio(XCVR_OFF_GPIO);
}
@@ -75,16 +75,16 @@
{
/* Configure SPI chip selects if 1) SSI is not disabled, and 2) the weak function
- * lm3s_ssiinitialize() has been brought into the link.
+ * lm_ssiinitialize() has been brought into the link.
*/
#if !defined(CONFIG_SSI0_DISABLE)
diff --git a/nuttx/configs/lm3s6432-s2e/src/up_ssi.c b/nuttx/configs/lm3s6432-s2e/src/up_ssi.c
index a7844a979..5468e2b4d 100644
--- a/nuttx/configs/lm3s6432-s2e/src/up_ssi.c
+++ b/nuttx/configs/lm3s6432-s2e/src/up_ssi.c
@@ -79,7 +79,7 @@
/* Dump GPIO registers */
#ifdef SSI_VERBOSE
-# define ssi_dumpgpio(m) lm3s_dumpgpio(SDCCS_GPIO, m)
+# define ssi_dumpgpio(m) lm_dumpgpio(SDCCS_GPIO, m)
#else
# define ssi_dumpgpio(m)
#endif
@@ -93,30 +93,30 @@
************************************************************************************/
/************************************************************************************
- * Name: lm3s_ssiinitialize
+ * Name: lm_ssiinitialize
*
* Description:
* Called to configure SPI chip select GPIO pins for the MDL-S2E.
*
************************************************************************************/
-void weak_function lm3s_ssiinitialize(void)
+void weak_function lm_ssiinitialize(void)
{
/* Configure the SPI CS GPIO */
- ssi_dumpgpio("lm3s_ssiinitialize() Entry)");
- lm3s_configgpio(SSICS_GPIO);
- ssi_dumpgpio("lm3s_ssiinitialize() Exit");
+ ssi_dumpgpio("lm_ssiinitialize() Entry)");
+ lm_configgpio(SSICS_GPIO);
+ ssi_dumpgpio("lm_ssiinitialize() Exit");
}
/****************************************************************************
* The external functions, lm3s_spiselect and lm3s_spistatus must be provided
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi.h).
* All othermethods (including up_spiinitialize()) are provided by common
* logic. To use this common SPI logic on your board:
*
* 1. Provide lm3s_spiselect() and lm3s_spistatus() functions in your
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.
* 2. Add a call to up_spiinitialize() in your low level initialization
@@ -128,21 +128,21 @@ void weak_function lm3s_ssiinitialize(void)
*
****************************************************************************/
-void lm3s_spiselect(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool selected)
+void lm_spiselect(FAR struct spi_dev_s *dev, enum spi_dev_e devid, bool selected)
{
ssidbg("devid: %d CS: %s\n", (int)devid, selected ? "assert" : "de-assert");
- ssi_dumpgpio("lm3s_spiselect() Entry");
+ ssi_dumpgpio("lm_spiselect() Entry");
if (devid == SPIDEV_MMCSD)
{
/* Assert the CS pin to the card */
- lm3s_gpiowrite(SDCCS_GPIO, !selected);
+ lm_gpiowrite(SDCCS_GPIO, !selected);
}
- ssi_dumpgpio("lm3s_spiselect() Exit");
+ ssi_dumpgpio("lm_spiselect() Exit");
}
-uint8_t lm3s_spistatus(FAR struct spi_dev_s *dev, enum spi_dev_e devid)
+uint8_t lm_spistatus(FAR struct spi_dev_s *dev, enum spi_dev_e devid)
{
ssidbg("Returning SPI_STATUS_PRESENT\n");
return SPI_STATUS_PRESENT;
@@ -93,30 +93,30 @@
}
/****************************************************************************
- * The external functions, lm3s_spiselect and lm3s_spistatus must be provided
+ * The external functions, lm_spiselect and lm_spistatus must be provided
* by board-specific logic. The are implementations of the select and status
* methods SPI interface defined by struct spi_ops_s (see include/nuttx/spi.h).
@@ -93,30 +93,30 @@
* logic. To use this common SPI logic on your board:
*
- * 1. Provide lm3s_spiselect() and lm3s_spistatus() functions in your
+ * 1. Provide lm_spiselect() and lm_spistatus() functions in your
* board-specific logic. This function will perform chip selection and
* status operations using GPIOs in the way your board is configured.